#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  missingnotice_tests.py
#
#  Copyright 2018 Jonathan Golder <jonathan@golderweb.de>
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#  MA 02110-1301, USA.
#
#

"""
Test module bot/missingnotice.py
"""

import unittest
from unittest import mock  # noqa

import pywikibot

import context  # noqa
from bots.missingnotice import MissingNoticeBot  # noqa


class TestMissingNoticeBot(unittest.TestCase):
    """
    Test class MissingNoticeBot
    """

    def setUp(self):
        genFactory = pywikibot.pagegenerators.GeneratorFactory()
        self.MissingNoticeBot = MissingNoticeBot(genFactory)
        self.MissingNoticeBot.categorized_articles = [ "Deutschland",
                                                       "Max_Schlee",
                                                       "Hodeng-Hodenger" ]

    @mock.patch( 'sqlalchemy.engine.Engine.execute',
                 return_value=( { "page_title": b"a", },
                                { "page_title": b"b", },
                                { "page_title": b"c", },
                                { "page_title": b"d", }, ) )
    def test_get_categorized_articles(self, execute_mock):
        """
        Test method get_categorized_articles()
        """
        self.assertFalse(execute_mock.called)

        result = MissingNoticeBot.get_categorized_articles()

        self.assertTrue(execute_mock.called)
        self.assertEqual(result, ["a", "b", "c", "d"] )

    def test_treat_articles( self ):
        """
        Test method treat_articles()
        """

        # articles with notice
        a = pywikibot.Page(pywikibot.Site(), "Deutschland" )
        b = pywikibot.Page(pywikibot.Site(), "Max_Schlee" )
        c = pywikibot.Page(pywikibot.Site(), "Hodeng-Hodenger#Test" )
        # articles without notice
        x = pywikibot.Page(pywikibot.Site(), "Quodvultdeus" )
        y = pywikibot.Page(pywikibot.Site(), "Zoo_Bremen" )
        z = pywikibot.Page(pywikibot.Site(), "Nulka#Test" )

        cases = ( ( ( a, b, c ), list() ),
                  ( ( x, y, z ), [ "[[Quodvultdeus]]",
                                   "[[Zoo Bremen]]",
                                   "[[Nulka#Test]]" ]),
                  ( ( a, b, y, z ), [ "[[Zoo Bremen]]",
                                      "[[Nulka#Test]]" ]), )

        for case in cases:
            res = self.MissingNoticeBot.treat_articles( case[0] )

            self.assertEqual( res, case[1] )


if __name__ == '__main__':
    unittest.main()
